@@ -3,16 +3,17 @@
 PDF Backend: pdfMiner
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function,\
+ unicode_literals
 
 import sys
 import logging
-import chardet
-
 from io import BytesIO
 from re import compile
 
+# Character Detection Helper
+import chardet
+
 # Find URLs in text via regex
 from . import extractor
 from .libs.xmp import xmp_to_dict
@@ -20,17 +21,18 @@ from .libs.xmp import xmp_to_dict
 # Setting `psparser.STRICT` is the first thing to do because it is
 # referenced in the other pdfparser modules
 from pdfminer import settings as pdfminer_settings
-from pdfminer import psparser
-from pdfminer.pdfdocument import PDFDocument
-from pdfminer.pdfparser import PDFParser
-from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
-from pdfminer.pdfpage import PDFPage
-from pdfminer.pdftypes import resolve1, PDFObjRef
-from pdfminer.converter import TextConverter
-from pdfminer.layout import LAParams
 
-# Moved from under psparser
 pdfminer_settings.STRICT = False
+from pdfminer import psparser  # noqa: E402
+from pdfminer.pdfdocument import PDFDocument  # noqa: E402
+from pdfminer.pdfparser import PDFParser  # noqa: E402
+from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter\
+  # noqa: E402
+from pdfminer.pdfpage import PDFPage  # noqa: E402
+from pdfminer.pdftypes import resolve1, PDFObjRef  # noqa: E402
+from pdfminer.converter import TextConverter  # noqa: E402
+from pdfminer.layout import LAParams  # noqa: E402
+
 
 logger = logging.getLogger(__name__)
 
@@ -74,16 +76,18 @@ def make_compat_str(in_str):
 
 class Reference(object):
     """ Generic Reference """
+
     ref = ""
     reftype = "url"
     page = 0
 
     def __init__(self, uri, page=0):
-
         self.ref = uri
         self.reftype = "url"
         self.page = page
+
         self.pdf_regex = compile(r"\.pdf(:?\?.*)?$")
+
         # Detect reftype by filetype
         if self.pdf_regex.search(uri.lower()):
             self.reftype = "pdf"
@@ -119,6 +123,7 @@ class ReaderBackend(object):
 
     The job of a Reader is to extract Text and Links.
     """
+
     text = ""
     metadata = {}
     references = set()
@@ -180,7 +185,11 @@ class ReaderBackend(object):
 
 
 class PDFMinerBackend(ReaderBackend):
-    def __init__(self, pdf_stream, password="", pagenos=[], maxpages=0):
+    def __init__(self, pdf_stream, password="", pagenos=None, maxpages=0):
+        # noqa: C901
+        if pagenos is None:
+            pagenos = []
+
         ReaderBackend.__init__(self)
         self.pdf_stream = pdf_stream
 
@@ -207,8 +216,10 @@ class PDFMinerBackend(ReaderBackend):
         # Extract Content
         text_io = BytesIO()
         rsrcmgr = PDFResourceManager(caching=True)
-        converter = TextConverter(rsrcmgr, text_io, codec="utf-8",
-                                  laparams=LAParams(), imagewriter=None)
+        converter = TextConverter(
+            rsrcmgr, text_io, codec="utf-8", laparams=LAParams(),
+            imagewriter=None
+        )
         interpreter = PDFPageInterpreter(rsrcmgr, converter)
 
         self.metadata["Pages"] = 0
@@ -291,9 +302,6 @@ class PDFMinerBackend(ReaderBackend):
         if "URI" in obj_resolved:
             if isinstance(obj_resolved["URI"], PDFObjRef):
                 return self.resolve_PDFObjRef(obj_resolved["URI"])
-            else:
-                return Reference(obj_resolved["URI"].decode("utf-8"),
-                                 self.curpage)
 
         if "A" in obj_resolved:
             if isinstance(obj_resolved["A"], PDFObjRef):
